@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Define and roll musical dice
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -225,7 +225,7 @@ has ionian_mask => (
     is      => 'ro',
     isa     => ArrayRef[Str],
     default => sub {
-        [qw(I ii iii IV V iv viio)],
+        [qw(I ii iii IV V vi viio)],
     },
 );
 
@@ -698,7 +698,7 @@ Music::Dice - Define and roll musical dice
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -985,7 +985,7 @@ Default:
 
 The mask of Ionian mode triad types.
 
-Default: C<[I ii iii IV V iv viio]>
+Default: C<[I ii iii IV V vi viio]>
 
 =head2 dorian_mask
 
